
329
9
장
입출력 작업
●
저장 비용 감소
●
백업 비용 감소
●
네트워크 트래픽 감소
●
네트워크 속도 개선(원격 서버의 데이터 저장 및 검색 속도 개선)
●
I
/
O
병목을 줄여서
CPU
사용량 증가
9.3.3
배열 작업
파이썬 기본 입출력에 관한 절에서 이미
NumPy
가 빠른
ndarray
객체 읽기 및 쓰기 기능을 가
졌음을 살펴보았다.
ndarray
객체를 읽고 쓸 때
PyTables
도 아주 빠르고 효율적이다. 또한
PyTables
은 계층적인 데이터베이스 구조를 가졌기 때문에 그에 따른 이점도 있다.
In [177]: %%time
arr_int = h5.create_array('/', 'integers', ran_int)
➊
arr_flo = h5.create_array('/', 'floats', ran_flo)
➋
CPU times: user 4.26 ms, sys: 37.2 ms, total: 41.5 ms
Wall time: 46.2 ms
In [178]: h5
➌
Out[178]: File(filename=/Users/yves/Temp/data/pytab.h5, title='', mode='w',
root_uep='/', filters=Filters(complevel=0, shuffle=False,
bitshuffle=False, fletcher32=False, ...